Index: omaha_hash_calculator.h |
diff --git a/omaha_hash_calculator.h b/omaha_hash_calculator.h |
index 208fd01e6acddf2629c6d96b6795db9ca68cf1e5..52ac1b75fd5a9227195bb9f535f5a19513a92f35 100644 |
--- a/omaha_hash_calculator.h |
+++ b/omaha_hash_calculator.h |
@@ -40,6 +40,11 @@ class OmahaHashCalculator { |
return hash_; |
} |
+ const std::vector<char>& raw_hash() const { |
+ DCHECK(!raw_hash_.empty()) << "Call Finalize() first"; |
+ return raw_hash_; |
+ } |
+ |
static bool RawHashOfData(const std::vector<char>& data, |
std::vector<char>* out_hash); |
@@ -49,9 +54,10 @@ class OmahaHashCalculator { |
static std::string OmahaHashOfData(const std::vector<char>& data); |
private: |
// If non-empty, the final base64 encoded hash. Will only be set to |
// non-empty when Finalize is called. |
std::string hash_; |
+ std::vector<char> raw_hash_; |
// Init success |
bool valid_; |
@@ -49,9 +54,10 @@ class OmahaHashCalculator { |
static std::string OmahaHashOfData(const std::vector<char>& data); |
private: |
- // If non-empty, the final base64 encoded hash. Will only be set to |
- // non-empty when Finalize is called. |
+ // If non-empty, the final base64 encoded hash and the raw hash. Will only be |
+ // set to non-empty when Finalize is called. |
std::string hash_; |